-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------

function BodyLadder:StartActivity()
	print("START! -- BodyLadder:StartActivity()!");
	--These 4 seem to be in every mission.  Not sure what they do, but I don't want to mess with them just in case they're important. 
	self.FightStage = { NOFIGHT = 0, DEFENDING = 1, ATTACK = 2, FIGHTSTAGECOUNT = 3 };
	self.AreaTimer = Timer();
	self.StepTimer = Timer();
	self.SpawnTimer = Timer();
	--Time since a zombie has spawned.
	self.ZSpawn = Timer();
	--If the game is over yet.
	self.gameover = 0;
	--This is how long before a zombie should be spawned.  This way we can change it mid-level.
	ztime = 3000;
	--Side of the screen to spawn a zombie on.  Changes every time.  0 = left, 1 = right.
	self.zside = 0;
	--This is set whenever we interrupt the HEIGHT: message to show that you've achieved something.
	self.InterruptTimer = Timer();
	self.Interrupt = 0;
	--The player's height.
	self.height = 0;
	--The current checkpoint.
	self.checkpoint = 0;
	--Give the player no money.
	ActivityMan:GetActivity():SetTeamFunds(0,0);
	--Make the player.  Give them a shovel.  Set it as the brain.  Switch the view to it.
	playerActor = CreateAHuman("Survivor");
	playerActor.Pos = Vector(160,2435);
	playerActor.Team = 0;
	playerActor:AddInventoryItem(CreateHDFirearm("Baseball Bat"));
	MovableMan:AddActor(playerActor);
	self:SetPlayerBrain(playerActor, 0);
	self:SetLandingZone(playerActor.Pos, 0);
	self:SwitchToActor(playerActor, 0, self:GetTeamOfPlayer(0));
	--Play the music.
	AudioMan:ClearMusicQueue();
	AudioMan:PlayMusic("Body Ladder.rte/Naturally_Industrial.ogg", -1, -1);
end

-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------

function BodyLadder:PauseActivity(pause)
	print("PAUSE! -- BodyLadder:PauseActivity()!");
end

-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------

function BodyLadder:EndActivity()
	print("END! -- BodyLadder:EndActivity()!");
	self.gameover = 1;
	if self.WinnerTeam == Activity.TEAM_2 then
		self:ResetMessageTimer(Activity.PLAYER_1);
            	FrameMan:ClearScreenText(Activity.PLAYER_1);
		FrameMan:SetScreenText("You're dead.  You were the last guy, too.  So much for the human race.", Activity.PLAYER_1, 0, 5000, false);
	else
		self:ResetMessageTimer(Activity.PLAYER_1);
            	FrameMan:ClearScreenText(Activity.PLAYER_1);
		FrameMan:SetScreenText("You ran out of oxygen up in space, but uh...  I guess you win.", Activity.PLAYER_1, 0, 5000, false);
	end
end

-----------------------------------------------------------------------------------------
-- Update Activity-----------------------------------------------------------------------------------------

function BodyLadder:UpdateActivity()
	if MovableMan:IsActor(playerActor) then
		--Make the place that the screen flies to on death the player's position.
		self:SetObservationTarget(playerActor.Pos, Activity.PLAYER_1);
		--2441 = map height - ground level, that way the player doesn't start off with 64 height.
		--Also, only set the height if they player has gone above it.  Otherwise it'll decrease.
		if math.ceil(-playerActor.Pos.Y + 2441) > self.height then
			self.height = math.ceil(-playerActor.Pos.Y + 2441);
		end
		--Make sure the message isn't being interrupted by, for instance, "NEW WEAPON!"
		if self.InterruptTimer:LeftTillSimMS(self.Interrupt) <= 0 then
			FrameMan:SetScreenText("HEIGHT: " .. self.height, Activity.PLAYER_1, 0, 1, false);
		end

		--Spawn more zombies when needed.
		if -self.ZSpawn:LeftTillSimMS(0) > ztime then
			--All the zombies that could be spawned.
			local zlist = {"Zombie Thin", "Zombie Medium", "Zombie Fat"}
			local zombie = CreateAHuman(zlist[math.random(#zlist)], "Body Ladder.rte");
			--Spawn it on the proper side and switch it for the next one.
			if self.zside == 0 then
				--Make the zombie go to the other side of the screen, meaning they'll eventually get the player.
				--The reason I don't use the player's position instead is that once they've arrived there, they stop.
				zombie:AddAISceneWaypoint(Vector(320,playerActor.Pos.Y));
				zombie.Pos = Vector(10,playerActor.Pos.Y);
				self.zside = 1;
			else
				zombie:AddAISceneWaypoint(Vector(0,playerActor.Pos.Y));
				zombie.Pos = Vector(310,playerActor.Pos.Y);
				self.zside = 0;
			end
			--Set the zombie's Team.
			zombie.Team = 1;
			zombie.AIMode = Actor.AIMODE_GOTO;
			--Spawn the zombie.
			MovableMan:AddActor(zombie);
			self.ZSpawn:Reset();
		end
		
		--If the player has reached the first checkpoint, award him, but speed up the zombies.
		if self.height > 100 and self.checkpoint < 1 then
			--Tell the game that the HEIGHT: message is being interrupted to display this one.
			self.Interrupt = 5000;
			self.InterruptTimer:Reset();
			self:ResetMessageTimer(Activity.PLAYER_1);
            		FrameMan:ClearScreenText(Activity.PLAYER_1);
			FrameMan:SetScreenText("Height of 100 reached!  New weapon: Pistol.  Zombie spawn speed increased!", Activity.PLAYER_1, 0, 5000, false);
			playerActor:AddInventoryItem(CreateHDFirearm("Pistol"));
			ztime = 2750;
			self.checkpoint = 1;
		end

		if self.height > 250 and self.checkpoint < 2  then
			--Tell the game that the HEIGHT: message is being interrupted to display this one.
			self.Interrupt = 5000;
			self.InterruptTimer:Reset();
			self:ResetMessageTimer(Activity.PLAYER_1);
            		FrameMan:ClearScreenText(Activity.PLAYER_1);
			FrameMan:SetScreenText("Height of 250 reached!  New weapon: Auto Pistol.  Zombie spawn speed increased!", Activity.PLAYER_1, 0, 5000, false);
			playerActor:AddInventoryItem(CreateHDFirearm("Auto Pistol"));
			ztime = 2500;
			self.checkpoint = 2;
		end

		if self.height > 500 and self.checkpoint < 3  then
			--Tell the game that the HEIGHT: message is being interrupted to display this one.
			self.Interrupt = 5000;
			self.InterruptTimer:Reset();
			self:ResetMessageTimer(Activity.PLAYER_1);
            		FrameMan:ClearScreenText(Activity.PLAYER_1);
			FrameMan:SetScreenText("Height of 750 reached!  New weapon: Shotgun.  Zombie spawn speed increased!", Activity.PLAYER_1, 0, 5000, false);
			playerActor:AddInventoryItem(CreateHDFirearm("Shotgun"));
			ztime = 2250;
			self.checkpoint = 3;
		end

		if self.height > 750 and self.checkpoint < 4  then
			--Tell the game that the HEIGHT: message is being interrupted to display this one.
			self.Interrupt = 5000;
			self.InterruptTimer:Reset();
			self:ResetMessageTimer(Activity.PLAYER_1);
            		FrameMan:ClearScreenText(Activity.PLAYER_1);
			FrameMan:SetScreenText("Height of 1000 reached!  New weapon: Assault Rifle.  Zombie spawn speed increased!", Activity.PLAYER_1, 0, 5000, false);
			playerActor:AddInventoryItem(CreateHDFirearm("Assault Rifle"));
			ztime = 2000;
			self.checkpoint = 4;
		end

		if self.height > 1000 and self.checkpoint < 5  then
			--Tell the game that the HEIGHT: message is being interrupted to display this one.
			self.Interrupt = 5000;
			self.InterruptTimer:Reset();
			self:ResetMessageTimer(Activity.PLAYER_1);
            		FrameMan:ClearScreenText(Activity.PLAYER_1);
			FrameMan:SetScreenText("Height of 1000 reached!  New weapon: Auto Shotgun.  Zombie spawn speed increased!", Activity.PLAYER_1, 0, 5000, false);
			playerActor:AddInventoryItem(CreateHDFirearm("Auto Shotgun"));
			ztime = 1750;
			self.checkpoint = 5;
		end

		if self.height > 1500 and self.checkpoint < 6  then
			--Tell the game that the HEIGHT: message is being interrupted to display this one.
			self.Interrupt = 5000;
			self.InterruptTimer:Reset();
			self:ResetMessageTimer(Activity.PLAYER_1);
            		FrameMan:ClearScreenText(Activity.PLAYER_1);
			FrameMan:SetScreenText("Height of 3000 reached!  New weapon: Heavy Auto Shotgun.  Zombie spawn speed increased!", Activity.PLAYER_1, 0, 5000, false);
			playerActor:AddInventoryItem(CreateHDFirearm("Heavy Auto Shotgun"));
			ztime = 1000;
			self.checkpoint = 6;
		end

		if self.height > 2000 and self.checkpoint < 7 then
			--Tell the game that the HEIGHT: message is being interrupted to display this one.
			self.Interrupt = 5000;
			self.InterruptTimer:Reset();
			self:ResetMessageTimer(Activity.PLAYER_1);
            		FrameMan:ClearScreenText(Activity.PLAYER_1);
			FrameMan:SetScreenText("Height of 4000 reached!  New weapon: Gatling Gun.  You're almost there!", Activity.PLAYER_1, 0, 5000, false);
			playerActor:AddInventoryItem(CreateHDFirearm("Gatling Gun"));
			ztime = 500;
			self.checkpoint = 7;
		end

		if self.height > 2250 and self.gameover == 0 then
			playerActor.Health = 0;
			self.WinnerTeam = Activity.TEAM_1;
			ActivityMan:EndActivity();
		end

		--If the player is outside of the screen, bump them back.  Othwerwise they fall off, and it's annoying.
		if playerActor.Pos.X > 320 then
			playerActor.Vel.X = -2;
		elseif playerActor.Pos.X < 0 then
			playerActor.Vel.X = 2;
		end

	elseif self.gameover == 0 then
		self.WinnerTeam = Activity.TEAM_2;
		ActivityMan:EndActivity();
	end
end